# This script was written by Michel Arboi <mikhail@nessus.org>
# It is released under the GNU Public Licence.

if(description)
{
 script_id(17975);
 script_version ("$Revision: 1.108 $");
 
 name["english"] = "Identify unknown services with GET";
 script_name(english:name["english"]);
 
 desc["english"] = "
Synopsis :

This plugin performs service detection.

Description :

This plugin is a complement of find_service1.nasl. It sends a GET
request to the remaining unknown services and tries to identify 
them.

Risk factor : 

None";


 script_description(english:desc["english"]);
 
 summary["english"] = "Sends 'GET' to unknown services and look at the answer";
 script_summary(english:summary["english"]);
 
 script_category(ACT_GATHER_INFO); 
 script_timeout(0);
 script_copyright(english:"This script is Copyright (C) 2005 Michel Arboi");
 script_family(english: "Service detection");

 if ( NASL_LEVEL < 3203 )
  script_dependencie("find_service.nes", "cifs445.nasl");
 else
  script_dependencie("find_service.nasl", "cifs445.nasl");
# Do *not* add a port dependency  on "Services/unknown"
# Some scripts must run after this script even if there are no
# unknown services
 exit(0);
}

#
include("misc_func.inc");
include("global_settings.inc");

if ( get_kb_item("global_settings/disable_service_discovery") ) exit(0);


port = get_unknown_svc();
if (! port) exit(0);
if (! get_port_state(port)) exit(0);

# If the service displays a banner on connection, find_service.c does not
# send a GET request. However, if a GET request was sent and the service
# remains silent, the get_http KB entry is void

r0 = get_kb_item('FindService/tcp/'+port+'/spontaneousHex');	# Banner?
if ( ! isnull(r0) )
     r0 = hex2raw(s:r0);
else 
     r0 = get_kb_item('FindService/tcp/'+port+'/spontaneous');
get_sent = 1;

r0_len = strlen(r0);
if (r0_len > 0)	# We have a spontaneous banner
{
 get_sent = 0;	# spontaneous banner => no GET request was sent by find_service

###################################################
######## Updates for "spontaneous" banners ########
###################################################

if (r0 =~ '^[0-9]+ *, *[0-9]+ *: *USERID *: *UNIX *: *[a-z0-9]+')
{
 debug_print('Fake IDENTD found on port ', port, '\n');
 register_service(port: port, proto: 'fake-identd');
 set_kb_item(name: 'fake_identd/'+port, value: TRUE);
 exit(0);
}

if (match(string: r0, pattern: 'CIMD2-A ConnectionInfo: SessionId = * PortId = *Time = * AccessType = TCPIP_SOCKET PIN = *'))
{
 report_service(port: port, svc: 'smsc');
 exit(0);
}

if (r0 == '\x00\x00\x00\x0D\xD5\xF2Who are you?\x0A\x00')
{
 # Port doc1lm (3161/tcp)
 # PatrolAgent (BMC Patrol)
 report_service(port: port, svc: 'patrol-agent');
 exit(0);
}


if ( "com.plumtree.content.rdbms.database" >< r0 )
{
 report_service(port: port, svc: 'java-plumtree-server');
 exit(0);
}

#
# aced0005 = header fo a serialized object stream 
# (java.io.ObjectOutputStream)
# 
if (r0_len >= 4 && substr(r0, 0, 3) == '\xAC\xED\x00\x05' )
{
 report_service(port: port, svc: 'java-listener');
 exit(0);
}

if ( '\x00\x00\x00\x0bSynergy' >< r0 )
{
 # Synergy Server
 report_service(port: port, svc: 'synergys');
 exit(0);
}

if ("HP OpenView Storage Data Protector" >< r0 )
{
 report_service(port: port, svc: 'hp_openview_dataprotector');
 exit(0);
}

# 00: 57 65 64 20 4a 75 6c 20 30 36 20 31 37 3a 34 37 Wed Jul 06 17:47
# 10: 3a 35 38 20 4d 45 54 44 53 54 20 32 30 30 35 0d :58 METDST 2005.
# 20: 0a . 
if (ereg(pattern:"^(Mon|Tue|Wed|Thu|Fri|Sat|Sun|Lun|Mar|Mer|Jeu|Ven|Sam|Dim) (Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|D[e]c|F[e]v|Avr|Mai|Ao[u]) *(0?[0-9]|[1-3][0-9]) [0-9]+:[0-9]+(:[0-9]+)?( *[ap]m)?( +[A-Z]+)? [1-2][0-9][0-9][0-9].?.?$", string:r0) ||
# Daytime in German
ereg(pattern:"^([01][0-9]|2[0-3]):[0-5][0-9]:[0-5][0-9] +([0-2][0-9]|3[01])\.(0[1-9]|1[0-2])\.(19|20)[0-9][0-9]$", string: r0)
)
{
 report_service(port: port, svc: 'daytime');
 exit(0);
}

# Possible outputs:
# |/dev/hdh|Maxtor 6Y160P0|38|C|
# |/dev/hda|ST3160021A|UNK|*||/dev/hdc|???|ERR|*||/dev/hdg|Maxtor 6B200P0|UNK|*||/dev/hdh|Maxtor 6Y160P0|38|C|
if (r0 =~ '^(\\|/dev/[a-z0-9/-]+\\|[^|]*\\|[^|]*\\|[^|]\\|)+$')
{
 report_service(port: port, svc: 'hddtemp'); 
 exit(0); 
}

if (match(string: r0, pattern: '220 *FTP Server ready\r\n'))
{
 report_service(port: port, svc: 'ftp');
 exit(0);
}

# 00: 22 49 4d 50 4c 45 4d 45 4e 54 41 54 49 4f 4e 22 "IMPLEMENTATION"
# 10: 20 22 43 79 72 75 73 20 74 69 6d 73 69 65 76 65  "Cyrus timsieve
# 20: 64 20 76 32 2e 32 2e 33 22 0d 0a 22 53 41 53 4c d v2.2.3".."SASL
# 30: 22 20 22 50 4c 41 49 4e 22 0d 0a 22 53 49 45 56 " "PLAIN".."SIEV
# 40: 45 22 20 22 66 69 6c 65 69 6e 74 6f 20 72 65 6a E" "fileinto rej
# 50: 65 63 74 20 65 6e 76 65 6c 6f 70 65 20 76 61 63 ect envelope vac
# 60: 61 74 69 6f 6e 20 69 6d 61 70 66 6c 61 67 73 20 ation imapflags
# 70: 6e 6f 74 69 66 79 20 73 75 62 61 64 64 72 65 73 notify subaddres
# 80: 73 20 72 65 6c 61 74 69 6f 6e 61 6c 20 72 65 67 s relational reg
# 90: 65 78 22 0d 0a 22 53 54 41 52 54 54 4c 53 22 0d ex".."STARTTLS".
# a0: 0a 4f 4b 0d 0a .OK..
if (match(string: r0, pattern: '"IMPLEMENTATION" "Cyrus timsieved v*"*"SASL"*'))
{
 register_service(port: port, proto: 'sieve');
 security_note(port: port, data: 'Sieve mail filter daemon seems to be running on this port');
 exit(0);
}

# I'm not sure it should go here or in find_service2...
if (match(string: r0, pattern: '220 Axis Developer Board*'))
{
 report_service(port: port, svc: 'axis-developer-board');
 exit(0);
}

if (match(string: r0, pattern: '  \x5f\x5f\x5f           *Copyright (C) 1999, 2000, 2001, 2002 Eggheads Development Team'))
{
 report_service(port: port, svc: 'eggdrop');
 exit(0);
}

# Music Player Daemon from www.musicpd.org
if (ereg(string: r0, pattern: '^OK MPD [0-9.]+\n'))
{
 report_service(port: port, svc: 'mpd');
 exit(0);
}

# Eudora Internet Mail Server ACAP server.
if ("* Eudora-SET (IMPLEMENTATION Eudora Internet Mail Server" >< r0)
{
 report_service(port: port, svc: 'acap');
 exit(0);
}

# Sophos Remote Messaging / Management Server
if ("IOR:010000002600000049444c3a536f70686f734d6573736167696e672f4d657373616765526f75746572" >< r0)
{
 report_service(port: port, svc: 'sophos_rms');
 exit(0);
}

# Ipswitch Collaboration Suite WorkgroupShare Server.
if (egrep(pattern:"^OK WorkgroupShare .+ server ready", string:r0))
{
  report_service(port:port, svc:"WorkgroupShare");
  exit(0);
}

if (r0 =~ '^\\* *BYE ')
{
  register_service(port: port, proto:'imap');
  security_note(port: port, data: 'The IMAP server rejects connection from our host. We cannot test it');
  exit(0);
}

# General case should be handled by find_service_3digits
if (match(string: r0, pattern: '200 CommuniGatePro PWD Server * ready*'))
{
 report_service(port: port, svc: 'pop3pw');
 exit(0);
}


# Should be handled by find_service.nasl already
if (r0 =~ "^RFB 00[0-9]\.00")
{
  report_service(port:port, svc: "vnc");
  exit(0);
}
if (r0 =~ "^RFB 003\.889")
{
  register_service(port:port, proto:"ard");
  security_note(port:port, data:"Apple Remote Desktop is running on this port.");
  exit(0);
}


if (r0 =~ '^welcome to the pioneers-meta-server version [0-9]\\.')
{
 register_service(port:port, proto:'pioneers-meta-server');
 security_note(port:port, data:"A meta server for the game Pioneers is running on this port.");
 exit(0);
}

# MA 2008-08-30: AIX lpd - Yes! This is a "spontaneous" banner
if (r0 =~ "^[0-9]+-[0-9]+ ill-formed FROM address.$")
{
 register_service(port:port, proto:'lpd');
 security_note(port: port, 'An LPD server (probably AIX) is running on this
 port');
 exit(0);
}

# German W2K3 qotd
if (ereg(string: r0, multiline: 1, pattern: '..........\n\\((Federico Fellini|Juliette Grco|Berthold Brecht|Volksweisheit|Mark Twain|Bertrand Russell|Helen Markel|Fritz Muliar|Anatole France|Albert Einstein|Oscar Wilde|August von Kotzebue|Tschechisches Sprichwort|Schweizer Sprichwort|Mark Twain)\\)$'))
{
 register_service(port:port, proto: "qotd");
 security_note(port: port, data: "qotd seems to be running on this port");
 exit(0);
}

# From Jim Heifetz
# Runs on port 10007 of z/OS Communication Server
# It always returns an eight digit number.

if (r0 =~ '^0000[0-9][0-9][0-9][0-9]$')
{
 register_service(port:port, proto:"mvs-capacity");	# should we call it bpxoinit?
 security_note(port: port, data: "BPXOINIT (MVS capacity) seems to be running on this port");
 exit(0);
}

if ("220 Ipswitch Notification Server" >< r0)
{
  register_service(port:port, proto:'ipswitch_ns');
  security_note(
    port:port, 
    data:"An Ipswitch Notification Server is running on this port."
  );
 exit(0);
}

if (":onx{" >< r0 && ':name["shinkuro"]' >< r0 && ':verb["hello"]' >< r0)
{
  register_service(port:port, proto:'shinkuro');
  security_note(
    port:port, 
    data:"A Shinkuro peer is running on this port."
  );
 exit(0);
}

# Submitted by Timothy Smith.
#
# nb: default port is TCP 8181.
if (
  "<KU_goodbye>Access not allowed" >< r0 && 
  "Check the InterMapper server&apos;s" >< r0
)
{
  register_service(port:port, proto:'intermapperd');
  security_note(
    port:port, 
    data:'An InterMapper service is listening on this port.'
  );
 exit(0);
}

# Submitted by w laoye.
#
# Spontaneous banner; eg,
# 
#   Temp.= 31.0, 37.0, 37.0; Rot.= 3970, 2576, 2700
#   Vcore = 1.74, 1.74; Volt. = 3.38, 5.08, 12.40, -11.35, -4.90
if (
  (stridx(r0, "Temp.=") == 0 || stridx(r0, '\nTemp.=') == 0) &&
  "; Rot.= " >< r0 &&
  '\nVcore = ' >< r0 &&
  "; Volt. = " >< r0
)
{
  register_service(port:port, proto:'mbmon');
  security_note(
    port:port, 
    data:'An mbmon (MotherBoard Monitor) daemon is listening on this port.'
  );
 exit(0);
}

# Spontaneous banner on TCP port 5405 - For example
# 0x00:  1B 00 02 00 54 49 54 41 4E 49 43 2D 42 44 43 00 ....TITANIC-BDC.
# 0x10:  00 00 00 00 00 00 01 00 01 00 00 00 00          .............
if (r0_len == 29 && substr(r0, 0, 3) == '\x1B\x00\x02\x00' &&
    substr(r0, r0_len - 8) == '\x00\x01\x00\x01\x00\x00\x00\x00')
{
  for (i = 4; i < r0_len && r0[i] != '\0'; i ++)
   ;  
  register_service(port:port, proto: "netsupport");
  security_note(port: port, data: "NetSupport client is running on this port");
  if (i > 4)
   security_note(port: port, 
data: 'According to NetSupport, the name of this host is\n' + substr(r0, 4, i - 1));
  exit(0);
}

# Spontaneous banner from hudlite-server 1.4.6:
#   :HUDserver NOTICE AUTH :*** Looking up your hostname...
#   :HUDserver NOTICE AUTH :*** Checking Ident
#   :HUDserver NOTICE AUTH :*** No Ident response
#   :HUDserver NOTICE AUTH :*** Found your hostname
if (":HUDserver NOTICE AUTH" >< r0)
{
  register_service(port:port, proto:'irc');
  security_note(
    port:port, 
    data:'An IRC server used by HUDlite-server, a backend for HUDlite,\nis running on this port.'
  );
 exit(0);
}

# Submitted by Michael Shor.
#
# Listens by default on TCP port 4949.
# Spontaneous banner; "# munin node at nixon.lab"
# More info: http://munin.projects.linpro.no/
if (r0 =~ '^# munin node at ')
{
 register_service(port:port, proto:"munin-node");
 security_note(port:port, data:'A munin-node daemon is listening on this port.  This service is used\nby the network monitoring tool Munin for monitoring individual hosts.');
 exit(0);
}

# Submitted by Adam J Richardson.
#
# Spontaneous banner:
#   :dircproxy NOTICE AUTH :Looking up your hostname...
#   :dircproxy NOTICE AUTH :Got your hostname.
# More info: http://dircproxy.securiweb.net/
if (r0 =~ '^:dircproxy NOTICE AUTH')
{
 register_service(port:port, proto:"dircproxy");
 security_note(port:port, data:'dircproxy, an IRC proxy server, is listening on this port.');
 exit(0);
}

# Submitted by Boogiebruva.
#
# Listens by default on TCP port 7777.
# Spontaneous banners: "cpu:  0.00 mem:-7223629312.00 s"
#                      "cpu:100.00 mem:83.63 swp:10032"
if (r0 =~ '^cpu: *[0-9][0-9.]+ mem:')
{
 register_service(port:port, proto:"jmond");
 security_note(port:port, data:'A jMon distributed resource monitor daemon is listening on this port.');

 exit(0);
}

# Listens on TCP port 2277.
# Spontaneous banner:
#   xqueue_id\0AAP0001752000146B2F1C8\0continue\010485760
if (r0 =~ '^xqueue_id\0[0-9A-H]+\0continue\0[0-9]+')
{
 register_service(port:port, proto:"kas-ap-process-server");
 security_note(port:port, data:'A Kaspersky Anti-Spam Filtration Server is listening on this port.');

 exit(0);
}

# Submitted by Aaron Michael Daugherty
#
# Listens by default on TCP port 4750.
# Spontaneous banners: "00000006-1;7350000001810;65;0;d50;d50;0"
#                      "00000006-1;7350000001810;65;0;b80;b80;0"
if (r0 =~ '^[0-9]+-[0-9];[0-9]+;[0-9]+;[0-9];[0-9a-h]+;[0-9a-h]+;[0-9]$')
{
 register_service(port:port, proto:"bladelogic_rscd");
 security_note(port:port, data:'A BladeLogic remote system call daemon (RSCD) is listening on this\nport.');

 exit(0);
}

# Submitted by Heath S. Hendrickson.
#
# Listens by default on TCP port 5280 by default.
if (r0 =~ '^[0-9]+ [0-9]+ pid$')
{
 register_service(port:port, proto:"autosys_client");
 security_note(port:port, data:'A Unicenter AutoSys Job Management remote client is listening on this\nport.');

 exit(0);
}

# Spontaneous banner:
#   RPY 0 0 . 0 118
#   Content-Type: application/beep+xml
#   
#   <greeting><profile uri="http://xml.resource.org/profiles/NULL/ECHO"/></greeting>END
# More info: http://www.rfc-editor.org/rfc/rfc3080.txt
if (
  'application/beep+xml' >< r0 &&
  '<greeting>' >< r0 &&
  r0 =~ '^RPY 0 0'
)
{
 register_service(port:port, proto:"beep");
 security_note(port:port, data:'A BEEP (Blocks Extensible Exchange Protocol) peer is listening on this\nport.');
 exit(0);
}

# Submitted by Zach Jansen.
#
# No default port.
# Spontaneous banner:
#   <AgentInfo><Version>6, 3, 2, 858</Version></AgentInfo>
if (
  stridx(r0, "<AgentInfo><Version>") == 0 &&
  # nb: 22 == strlen("</Version></AgentInfo>")
  (stridx(r0, "</Version></AgentInfo>") == strlen(r0) - 22 - 1)
)
{
  local_var report, v;

  register_service(port:port, proto:"patchlink_update_agent");

  report = "This is the listener port, or 'ping port', for a PatchLink Update Agent";
  v = strstr(r0, "<Version>") - "<Version>";
  v = v - strstr(v, "</Version");
  if (v)
  {
    v = str_replace(find:", ", replace:".", string:v);

    set_kb_item(name:"PatchLink_Update_Agent/"+port+"/Version", value:v);

    report += ',\n' +
      'which the banner identifies as version ' + v;
  }
  report += '.\n';
  
  security_note(port:port, data:report);
  exit(0);
}

# Listens on port 1793 by default if TCP support is enabled.
#
# Spontaneous banner:
#   0x00: 49 48 55 06 3E 00 IHU.>.
# More info: http://ihu.sourceforge.net/
if (strlen(r0) == 6 && r0 == raw_string("IHU", 0x06, 0x3e, 0x00))
{
  register_service(port:port, proto:"ihu");
  security_note(port:port, data:'An IHU (I Hear U) daemon is listening on this port.');
  exit(0);
}

# Submitted by Timothy Doty.
#
# Listens on port 3261 by default
#
# Spontaneous banner:
#   0x00: 1B 5B 32 4A 53 74 61 72 57 69 6E 64 20 69 53 43 .[2JStarWind iSC
#   0x10: 53 49 20 54 61 72 67 65 74 20 76 33 2E 35 2E 31 SI Target v3.5.1
#   0x20: 20 28 42 75 69 6C 64 20 32 30 30 37 31 32 30 34 (Build 20071204
#   0x30: 2C 20 57 69 6E 33 32 29 0D 0A 43 6F 70 79 72 69 , Win32)..Copyri
#   0x40: 67 68 74 20 28 63 29 20 52 6F 63 6B 65 74 20 44 ght (c) Rocket D
#   0x50: 69 76 69 73 69 6F 6E 20 53 6F 66 74 77 61 72 65 ivision Software
#   0x60: 20 32 30 30 33 2D 32 30 30 37 2E 20 41 6C 6C 20 2003-2007. All 
#   0x70: 72 69 67 68 74 73 20 72 65 73 65 72 76 65 64 2E rights reserved.
#   0x80: 0D 0A 0D 0A 0D 0A ...... 
# More info: http://www.rocketdivision.com/wind.html
if (stridx(r0, raw_string(0x1b, 0x5B, 0x32, 0x4a) + "StarWind iSCSI Target v") == 0)
{
  register_service(port:port, proto:"starwind_ctl");
  security_note(port:port, data:'The remote service is the control port for StarWind iSCSI Server.');
  exit(0);
}

# Submitted by Tom Van de Wiele 
#
# nb: these are possibly Witness ContactStore as OEM'd by Avaya.
if (
  "STNS:" >< r0 &&
  r0 =~ " TOKEN:[0-9]+:" && 
  r0 =~ "POOL:(meeting|ondemand|switch)\.assigned"
)
{
  register_service(port:port, proto:"avaya_slave_recorder");
  security_note(port:port, data:'An Avaya slave recorder is listening on this port.  It handles and\nlogs operational call data from various Avaya VoIP components.');
  exit(0);
}
# Spontaneous banner:
#   0x00: 31 20 50 49 4E 47 1B 1 PING. 
if (stridx(r0, raw_string("1 PING", 0x1b)) == 0)
{
  register_service(port:port, proto:"avaya_monitor");
  security_note(port:port, data:'A service for monitoring Avaya VoIP components is listening on this\nport.');
  exit(0);
}

# LANDesk Targeted Multicast Service.
if (stridx(r0, raw_string("TDMM", 0x1c, 0x00, 0x00, 0x00)) == 0)
{
  register_service(port:port, proto:"landesk_tmcsvc");
  security_note(port:port, data:"LANDesk's Targeted Multicast service is listening on this port.");
  exit(0);
}

# ircd
#
# Spontaneous banner:
#   :irc.example.com NOTICE AUTH :*** Looking up your hostname...\r\n
#   :irc.example.com NOTICE AUTH :*** Checking Ident\r\n
#   :irc.example.com NOTICE AUTH :*** No Ident response\r\n
#   :irc.example.com NOTICE AUTH :*** Found your hostname\r\n
if (
  (r0[0] == ':' && 'NOTICE AUTH :*** Looking up your hostname...\r\n' >< r0) ||
  (
    stridx(r0, 'ERROR :Trying to reconnect too fast.\r\n') == 0 ||
    (
      stridx(r0, 'ERROR :Closing Link: [') == 0 &&
      "(Throttled: Reconnecting too fast)" >< r0
    )
  )
)
{
  register_service(port:port, proto:"irc");
  security_note(port:port, data:"An IRC daemon is listening on this port.");
  exit(0);
}

# Jabber server
#
# Spontaneous banner:
#   <?xml version='1.0' encoding='utf-8'?><stream:stream xmlns="jabber:client" xmlns:stream="http://etherx.jabber.org/streams" version="1.0" id="ID:example-1034-1202610100015-0:0" to="client" from="localhost"><stream:features xmlns:ns16="urn:ietf:params:xml:ns:xmpp-tls" xmlns:ns15="urn:ietf:params:xml:ns:xmpp-sasl" xmlns:ns14="http://jabber.org/protocol/muc#user" xmlns:ns13="http://jabber.org/protocol/muc" xmlns:ns12="http://jabber.org/protocol/disco#items" xmlns:ns11="http://jabber.org/protocol/disco#info" xmlns:ns10="urn:ietf:params:xml:ns:xmpp-streams" xmlns:ns9="jabber:server:dialback" xmlns:ns8="jabber:server" xmlns:ns7="jabber:iq:roster" xmlns:ns6="jabber:iq:auth" xmlns:ns5="jabber:iq:private" xmlns:ns4="urn:ietf:params:xml:ns:xmpp-stanzas"><ns15:mechanisms></ns15:mechanisms></stream:features>
#
# nb: see also xmpp_server_detect.nasl -- not all such servers produce
#     a spontaneous banner by sending an unsolicited stream tag.
if (
  "jabber:client" >< r0 &&
  "xmlns:stream=" >< r0 &&
  "from=" >< r0 &&
  "id=" >< r0
)
{
  register_service(port:port, proto:"jabber");
  security_note(port:port, data:"A Jabber server is listening on this port.");
  exit(0);
}

# Submitted by Olaf Brandt
#
# Spontaneous banner:
#   0x00: 00 00 00 AE 01 41 63 74 69 76 65 4D 51 00 00 00 .....ActiveMQ...
#   0x10: 03 01 00 00 00 9C 00 00 00 07 00 14 54 69 67 68 ............Tigh
#   0x20: 74 45 6E 63 6F 64 69 6E 67 45 6E 61 62 6C 65 64 tEncodingEnabled
#   0x30: 01 01 00 09 43 61 63 68 65 53 69 7A 65 05 00 00 ....CacheSize...
#   0x40: 04 00 00 11 54 63 70 4E 6F 44 65 6C 61 79 45 6E ....TcpNoDelayEn
#   0x50: 61 62 6C 65 64 01 01 00 12 53 69 7A 65 50 72 65 abled....SizePre
#   0x60: 66 69 78 44 69 73 61 62 6C 65 64 01 00 00 11 53 fixDisabled....S
#   0x70: 74 61 63 6B 54 72 61 63 65 45 6E 61 62 6C 65 64 tackTraceEnabled
#   0x80: 01 01 00 15 4D 61 78 49 6E 61 63 74 69 76 69 74 ....MaxInactivit
#   0x90: 79 44 75 72 61 74 69 6F 6E 06 00 00 00 00 00 00 yDuration.......
#   0xA0: 75 30 00 0C 43 61 63 68 65 45 6E 61 62 6C 65 64 u0..CacheEnabled
#   0xB0: 01 01 .. 
if (
  'ActiveMQ' >< r0 &&
  (
    'MaxInactivityDuration' >< r0 ||
    'StackTraceEnabled' >< r0 ||
    'TcpNoDelayEnabled' >< r0 ||
    'TightEncodingEnabled' >< r0
  )
)
{
  register_service(port:port, proto:"activemq");
  security_note(port:port, data:"An ActiveMQ OpenWire transport connector is listening on this port.");
  exit(0);
}

# Submitted by Tim Ashby
#
# Spontaneous banner:
#   Hello from GP-Version Server V7.1a
if (stridx(r0, 'Hello from GP-Version Server V') == 0)
{
  register_service(port:port, proto:"teamcoherence");
  security_note(port:port, data:'The remote service is a Team Coherence server, used for version control\nand issue tracking.');
  exit(0);
}

#
# Keep qotd at the end of the list, as it may generate false detection
#

if (r0 =~ '^"[^"]+"[ \t\r\n]+[A-Za-z -]+[ \t\r\n]+\\([0-9]+(-[0-9]+)?\\)[ \t\r\n]+$')
{
  register_service(port:port, proto: "qotd");
  security_note(port: port, data: "qotd seems to be running on this port");
  exit(0);
}

}	# else: no spontaneous banner

###################################################
######## Updates for answers to GET / ...  ########
###################################################

k = 'FindService/tcp/'+port+'/get_http';
r = get_kb_item(k+'Hex');
if (strlen(r) > 0) r = hex2raw(s: r);
else r = get_kb_item(k);

r_len = strlen(r);
if (r_len == 0)
{
 if (get_sent			# Service did not anwer to GET
     && ! thorough_tests)	# We try again in "thorough tests"
  exit(0);

 soc = open_sock_tcp(port);
 if (! soc) exit(0);
 send(socket: soc, data: 'GET / HTTP/1.0\r\n\r\n');
 r = recv(socket:soc, length:4096);
 close(soc);
 r_len = strlen(r);
 if (r_len == 0)
 {
   debug_print('Service on port ', port, ' does not answer to "GET / HTTP/1.0"\n');
   exit(0);
 }
 set_kb_item(name: k, value: r);
 if ('\0' >< r) set_kb_item(name: k + 'Hex', value: hexstr(r));
}

# aka HTTP/0.9
if (r =~ '^[ \t\r\n]*<HTML>.*</HTML>' ||
# In case of truncated answer
    r=~ '^[ \t\r\n]*<HTML>[ \t\r\n]*<HEAD>.*</HEAD>[ \t\r\n]*<BODY( +[^>]+)?>')
{
 report_service(port: port, svc: 'www', banner: r);
 exit(0);
}

if (r == '[TS]\r\n')
{
 report_service(port: port, svc: 'teamspeak-tcpquery', banner: r);
 exit(0);
}

# gpsd (tcp/2947)
if (r == 'GPSD,G=?,E=?,T=?,T=?,T=?,P=?')
{
  register_service(port: port, proto: "gpsd");
  security_note(port: port, data: "gpsd is running on this port");
  exit(0);
}

# Veritas Backup Exec Remote Agent (6103/tcp)
if (r == '\xF6\xFF\xFF\xFF\x10\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00' )
{
  register_service(port: port, proto: "backup_exec");
  security_note(port: port, data: "Veritas Backup Exec Remote Agent is running on this port");
  exit(0);
}

if (r == 'gethostbyaddr: Error 0\n')
{
 register_service(port:port, proto:"veritas-netbackup-client");
 security_note(port:port, data:"Veritas NetBackup Client Service is running on this port");
 exit(0);
}

if ("GET / HTTP/1.0 : ERROR : INVALID-PORT" >< r)
{
 report_service(port: port, svc: 'auth', banner: r);
 exit(0);
}

if ('Host' >< r && 'is not allowed to connect to this MySQL server' >< r)
{
 register_service(port: port, proto: 'mysql');	# or wrapped?
 security_note(port: port, data: 
"A MySQL server seems to be running on this port but it
rejects connection from the Nessus scanner.");
  exit(0);
}

# The full message is:
# Host '10.10.10.10' is blocked because of many connection errors. Unblock with 'mysqladmin flush-hosts'
if ('Host' >< r && ' is blocked ' >< r && 'mysqladmin flush-hosts' >< r)
{
 register_service(port: port, proto: 'mysql');
 security_note(port: port, data: 
"A MySQL server seems to be running on this port but the 
Nessus scanner IP has been blacklisted.
Run 'mysqladmin flush-hosts' if you want complete tests.");
  exit(0);
}


if ( "Asterisk Call Manager" >< r )
{
 register_service(port: port, proto: 'asterisk');
 security_note(port: port, data: "An Asterisk Call Manager server is running on this port.");
  exit(0);
}

# Taken from find_service2 (obsolete, as the string contains a \0)
if (r_len == 3 && (r[2] == '\x10'||	# same test as find_service
                   r[2] == '\x0b') ||
    r == '\x78\x01\x07' || r == '\x10\x73\x0A' || r == '\x78\x01\x07' ||
    r == '\x08\x40\x0c' )
{
  register_service(port: port, proto: "msdtc");
  security_note(port: port, data: "An MSDTC server seems to be running on this port");
  exit(0);
}

# It seems that MS DTC banner is longer that 3 bytes, when we properly handle
# null bytes
# For example:
# 00: 90 a2 0a 00 80 94 .. 
# 00: F8 2D 0B 00 00 16 .-.... 
if ((r_len == 5 || r_len == 6) && r[3] == '\0' && 
     r[0] != '\0' && r[1] != '\0' && r[2] != '\0')
{
  register_service(port: port, proto: "msdtc");
  security_note(port: port, data: "An MSDTC server seems to be running on this port");
  exit(0);
}

if (
  r == '\x01Permission denied' || 
  (
    "lpd " >< r && 
    (
      "connected from invalid port" >< r ||
      "Print-services" >< r
    )
  )
)
{
  register_service(port:port, proto:'lpd');
  security_note(port: port, data: 'An LPD server is running on this port');
  exit(0);
}

# On port 264 - submitted by Jeff Healy
if (r == '\x59\x00\x00\x00' && port == 264)
{
 register_service(port:port, proto:'fw1-topology-download');
 security_note(port: port, data: 'Checkpoint Firewall-1 checkpoint topology download is running on this port');
 exit(0);
}

# Submitted by Shiva Subramanian
#
# nb: default port is TCP 8891.
if (
  r_len > 96 &&
  substr(r, 0, 3) == "PKGP" && 
  substr(r, 4, 23) =~ "^[0-9a-fA-F]+$"
)
{
  register_service(port:port, proto:"seagent");
  security_note(port:port, data:"CA Access Control's seagent seems to be listening on this port.");
  exit(0);
}

# from Universal IRC daemon when throttling connections.
#   "ERROR :Closing Link: [192.168.100.90] by lab.UnderNet.org (Your host is trying to (re)connect too fast -- throttled)"
if ("ERROR :Closing Link: [" >< r && "throttled" >< r)
{
  register_service(port:port, proto:'irc');
  security_note(
    port:port, 
    data:'An IRC server is running on this port and throttling connections from\nthe Nessus server.'
  );
 exit(0);
}

# Submitted by Ky6uk.
if (stridx(r, string("You are not authorized (", this_host(), ")\r\n<br>\r\n<a href=")) == 0)
{
 register_service(port:port, proto:"http_proxy");
 security_note(port:port, data:'An HTTP proxy from UserGate is listening on this port and blocking\nconnections from the Nessus server\'s IP.');

 exit(0);
}

# Submitted by Kimmo Torkkeli
if (
  stridx(r, "* OK SSP MagniComp SysInfo Server") == 0 ||
  stridx(r, "*-OK SSP MagniComp SysInfo Server") == 0
)
{
 register_service(port:port, proto:"mcsysinfod");
 security_note(port:port, data:'A MagniComp SysInfo agent is listening on this port.');

 exit(0);
}


#### Double check: all this should be handled by find_service.nes ####

# Spamd (port 783) - permissive Regex, just in case
if (r =~ '^SPAMD/[0-9.]+ [0-9]+ Bad header line:')
{
 register_service(port:port, proto:"spamd");
 security_note(port:port, data:"A SpamAssassin daemon is running on this port");
 exit(0);
}

if (r == 'GET / HTTP/1.0\r\n\r\n')
{
 report_service(port: port, svc: 'echo', banner: r);
 exit(0);
}

# Should we excluded port=5000...? (see find_service.c)
if (r =~ '^HTTP/1\\.[01] +[1-5][0-9][0-9] ')
{
 report_service(port: port, svc: 'www', banner: r);
 exit(0); 
}

# Suspicious: "3 digits" should appear in the banner, not in response to GET
if (r =~ '^[0-9][0-9][0-9]-?[ \t]')
{
 debug_print('"3 digits" found on port ', port, ' in response to GET\n');
 register_service(port: port, proto: 'three_digits');
 exit(0); 
}

if (r =~ "^RFB [0-9]")
{
  report_service(port:port, svc: "vnc");
  exit(0);
}

if (match(string: r, pattern: "Language received from client:*Setlocale:*"))
{
  report_service(port: port, svc: "websm");
  exit(0);
}

if (ereg(string: r, pattern: '^SSH-', icase: 0))
{
 report_service(port: port, svc: 'ssh');
 exit(0);
}

if (
  substr(r, 0, 3) == crap(data:raw_string(0), length:4) && 
  substr(r, 8, 18) == "00001$emsg="
)
{
 register_service(port:port, proto:"frontbase_db");
 security_note(port:port, data:"An instance of FrontBase is running on this port.");
 exit(0);
}

if (r == "<KU_goodbye>Protocol Error: XML data is not well-formed.</KU_goodbye>" 
)
{
 register_service(port:port, proto:"intermapperd");
 security_note(port:port, data:'An InterMapper service is listening on this port, and it allows\naccess from the Nessusd host.');
 exit(0);
}

# Listens by default on TCP port 2208 or 50000.
if (stridx(r, 'msg=MessageError\nresult-code=') == 0)
{
 register_service(port:port, proto:"hpiod");
 security_note(port:port, data:'An HP I/O backend daemon (hpiod) is listening on this port.');

 exit(0);
}

# Submitted by Francesco Conti
#
# More info: <http://sourceforge.net/projects/monopd/>
if (stridx(r, '<monopd><server version="') == 0)
{
 register_service(port:port, proto:"monopd");
 security_note(port:port, data:'monopd, a game server daemon for playing Monopoly-like board games, is\nlistening on this port.');

 exit(0);
}

# Submitted by Siraaj Khandkar.
if (stridx(r, '<boinc_gui_rpc_reply>') == 0)
{
 register_service(port:port, proto:"boinc_client");
 security_note(port:port, data:'A BOINC core client is listening on this port to allow GUI-based\nmanagement of the core client.');

 exit(0);
}

# Submitted by Christopher Rex.
#
# More info: <http://www.egghelp.org/>.
if ("(Eggdrop v" >< r && " (C) 1997 Robey Pointer " >< r)
{
 register_service(port:port, proto:"eggdrop");
 security_note(port:port, data:'An Eggdrop IRC bot is listening on this port.');

 exit(0);
}

if (stridx(r, raw_string(0x07, 0x00, 0x00, 0x00, 'APCX-OK')) == 0)
{
 register_service(port:port, proto:'activepdf_server');
 security_note(port:port, data:"An activePDF Server is listening on this port.");
 exit(0);
}


#### Some spontaneous banners are coming slowly, so they are wronly 
#### registered as answers to GET
 
if (r =~ '^(\\|/dev/[a-z0-9/-]+\\|[^|]*\\|[^|]*\\|[^|]\\|)+$')
{
 report_service(port: port, svc: 'hddtemp'); 
 exit(0); 
}


if((r_len > 8) && (substr(r,0,7) == '\x2E\x4E\x45\x54\x01\x00\x02\x00'))
{
 register_service(port:port, ipproto:"tcp", proto:"remoting_tcp");
 exit(0);
}

# MWAgent runs on TCP port 2222 by default.
#
# nb: checking 'r' rather than 'r0' avoids mis-identifying the service.
if (
  r =~ '^Agent Ready' &&
  "GET / HTTP/1.0 501 command not implemented ERROR" >< r
)
{
 register_service(port:port, proto:"mwagent");
 security_note(port:port, data:'A MicroWorld Agent Service is listening on this port.  This service is\nused, for example, with the eScan Internet Security application from\nMicroWorld Technologies.');
 exit(0);
}
