#
# (C) Tenable Network Security
#


  desc = "
Synopsis :

The remote host contains a peer-to-peer filesharing application. 

Description :

The remote host is running PeerCast, a peer-to-peer software package
that lets users broadcast streaming media. 

See also :

http://www.peercast.org/

Solution :

Make sure use of this program is in accordance with your corporate
security policy. 

Risk factor :

None";


if (description)
{
  script_id(18418);
  script_version("$Revision: 1.3 $");

  script_name(english:"PeerCast Detection");
  script_summary(english:"Detects PeerCast");
 
  script_description(english:desc);
 
  script_category(ACT_GATHER_INFO);
  script_family(english:"Peer-To-Peer File Sharing");

  script_copyright(english:"This script is Copyright (C) 2005-2007 Tenable Network Security");

  script_dependencies("http_version.nasl");
  script_require_ports("Services/www", 7144, 7145);

  exit(0);
}


include("http_func.inc");
include("http_keepalive.inc");


port = get_http_port(default:7144);
if (!get_port_state(port)) exit(0);


# Identify whether PeerCast is installed.
#
# nb: at least as of 0.1212, PeerCast doesn't provide a server response
#     header if the initial page is requested so we can't use
#     get_http_banner() to identify it.
req = http_get(item:"/html/en/index.htm", port:port);
res = http_keepalive_send_recv(port:port, data:req, bodyonly:FALSE);
if (res == NULL) exit(0);

if ("Server: PeerCast/" >< res)
{
  # Extract the Server response header.
  server = "";
  foreach line (split(res, keep:FALSE))
  {
    line = chomp(line);
    if (strlen(line) == 0) break;
    else if (line =~ "^Server:") server = line;
  }

  # If the server response header is indeed from PeerCast...
  if (server && "Server: PeerCast/")
  {
    set_kb_item(name:"PeerCast/installed", value:TRUE);

    ver = server - "Server: PeerCast/";
    if (!ver) ver = "unknown";
    set_kb_item(name:"PeerCast/"+port+"/version", value:ver);

   report = string(
      desc,
      "\n\n",
      "Plugin output :\n",
      "\n",
      "The remote PeerCast software uses the following Server response\n",
      "header :\n",
      "\n",
      "  ", server, "\n"
    );
    security_note(port:port, data:report);
  }
}
